@@ -15,15 +15,15 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Nat Friedman <nat@novell.com>
  *          Chris Toshok <toshok@ximian.com>
  *          Hans Petter Jansson <hpj@novell.com>
  */
 
-#include <config.h> 
+#include <config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -40,9 +40,11 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
-#include "libedataserver/e-dbhash.h"
-#include "libedataserver/e-db3-utils.h"
+#include "libebackend/e-dbhash.h"
+#include "libebackend/e-db3-utils.h"
+
 #include "libedataserver/e-data-server-util.h"
+#include "libedataserver/e-flag.h"
 
 #include "libebook/e-contact.h"
 
@@ -53,7 +55,7 @@
 
 #include "e-book-backend-file.h"
 
-#define d(x) x
+#define d(x)
 
 #define CHANGES_DB_SUFFIX ".changes.db"
 
@@ -63,7 +65,7 @@
 #define PAS_ID_PREFIX "pas-id-"
 #define SUMMARY_FLUSH_TIMEOUT 5000
 
-static EBookBackendSyncClass *e_book_backend_file_parent_class;
+G_DEFINE_TYPE (EBookBackendFile, e_book_backend_file, E_TYPE_BOOK_BACKEND_SYNC);
 
 struct _EBookBackendFilePrivate {
 	char     *dirname;
@@ -79,7 +81,7 @@ struct _EBookBackendFilePrivate {
 	void *reserved4;
 };
 
-static GStaticMutex global_env_lock = G_STATIC_MUTEX_INIT;
+G_LOCK_DEFINE_STATIC (global_env);
 static struct {
 	int ref_count;
 	DB_ENV *env;
@@ -165,7 +167,7 @@ e_book_backend_file_create_unique_id (void)
 	return g_strdup_printf (PAS_ID_PREFIX "%08lX%08X", time(NULL), c++);
 }
 
-static void 
+static void
 set_revision (EContact *contact)
 {
 	char time_string[25] = {0};
@@ -177,7 +179,7 @@ set_revision (EContact *contact)
 	if (tm)
 		strftime (time_string, 100, "%Y-%m-%dT%H:%M:%SZ", tm);
 	e_contact_set (contact, E_CONTACT_REV, time_string);
-	
+
 }
 
 static EBookBackendSyncStatus
@@ -191,7 +193,7 @@ do_create(EBookBackendFile  *bf,
 	char           *id;
 	char           *vcard;
 	const char *rev;
-	
+
 	g_assert (bf);
 	g_assert (vcard_req);
 	g_assert (contact);
@@ -305,15 +307,19 @@ e_book_backend_file_modify_contact (EBookBackendSync *backend,
 	DB             *db = bf->priv->file_db;
 	DBT            id_dbt, vcard_dbt;
 	int            db_error;
-	char          *id, *lookup_id;
+	const char    *id, *lookup_id;
 	char          *vcard_with_rev;
 
 	*contact = e_contact_new_from_vcard (vcard);
-	id = e_contact_get(*contact, E_CONTACT_UID);
+	id = e_contact_get_const (*contact, E_CONTACT_UID);
 
 	if (id == NULL)
 		return GNOME_Evolution_Addressbook_OtherError;
 
+	/* update the revision (modified time of contact) */
+	set_revision (*contact);
+	vcard_with_rev = e_vcard_to_string (E_VCARD (*contact), EVC_FORMAT_VCARD_30);
+
 	/* This is disgusting, but for a time cards were added with
            ID's that are no longer used (they contained both the uri
            and the id.) If we recognize it as a uri (file:///...) trim
@@ -325,23 +331,8 @@ e_book_backend_file_modify_contact (EBookBackendSync *backend,
 	else
 		lookup_id = id;
 
-	string_to_dbt (lookup_id, &id_dbt);	
-	memset (&vcard_dbt, 0, sizeof (vcard_dbt));
-	vcard_dbt.flags = DB_DBT_MALLOC;
-
-	/* get the old ecard - the one that's presently in the db */
-	db_error = db->get (db, NULL, &id_dbt, &vcard_dbt, 0);
-	if (0 != db_error) {
-		g_warning (G_STRLOC ": db->get failed with %s", db_strerror (db_error));
-		return GNOME_Evolution_Addressbook_ContactNotFound;
-	}
-	g_free (vcard_dbt.data);
-
-	/* update the revisio (modified time of contact) */
-	set_revision (*contact);
-	vcard_with_rev = e_vcard_to_string (E_VCARD (*contact), EVC_FORMAT_VCARD_30);
-	
-	string_to_dbt (vcard_with_rev, &vcard_dbt);	
+	string_to_dbt (lookup_id, &id_dbt);
+	string_to_dbt (vcard_with_rev, &vcard_dbt);
 
 	db_error = db->put (db, NULL, &id_dbt, &vcard_dbt, 0);
 
@@ -356,7 +347,6 @@ e_book_backend_file_modify_contact (EBookBackendSync *backend,
 	} else {
 		g_warning (G_STRLOC ": db->put failed with %s", db_strerror(db_error));
 	}
-	g_free (id);
 	g_free (vcard_with_rev);
 
 	if (0 == db_error)
@@ -413,11 +403,11 @@ e_book_backend_file_get_contact_list (EBookBackendSync *backend,
 	const char *search = query;
 	GList *contact_list = NULL;
 	EBookBackendSyncStatus status;
-	
+
 	d(printf ("e_book_backend_file_get_contact_list (%s)\n", search));
 	status = GNOME_Evolution_Addressbook_Success;
 	if (e_book_backend_summary_is_summary_query (bf->priv->summary, search)) {
-	
+
 		/* do a summary query */
 		GPtrArray *ids = e_book_backend_summary_search (bf->priv->summary, search);
 		int i;
@@ -477,7 +467,7 @@ e_book_backend_file_get_contact_list (EBookBackendSync *backend,
 
 		}
 		g_object_unref (card_sexp);
-		
+
 		if (db_error == DB_NOTFOUND) {
 			status = GNOME_Evolution_Addressbook_Success;
 		} else {
@@ -497,18 +487,15 @@ e_book_backend_file_get_contact_list (EBookBackendSync *backend,
 
 typedef struct {
 	EBookBackendFile *bf;
-	GMutex *mutex;
-	GCond *cond;
 	GThread *thread;
-	gboolean stopped;
+	EFlag *running;
 } FileBackendSearchClosure;
 
 static void
 closure_destroy (FileBackendSearchClosure *closure)
 {
 	d(printf ("destroying search closure\n"));
-	g_mutex_free (closure->mutex);
-	g_cond_free (closure->cond);
+	e_flag_free (closure->running);
 	g_free (closure);
 }
 
@@ -518,10 +505,8 @@ init_closure (EDataBookView *book_view, EBookBackendFile *bf)
 	FileBackendSearchClosure *closure = g_new (FileBackendSearchClosure, 1);
 
 	closure->bf = bf;
-	closure->mutex = g_mutex_new ();
-	closure->cond = g_cond_new ();
 	closure->thread = NULL;
-	closure->stopped = FALSE;
+	closure->running = e_flag_new ();
 
 	g_object_set_data_full (G_OBJECT (book_view), "EBookBackendFile.BookView::closure",
 				closure, (GDestroyNotify)closure_destroy);
@@ -538,21 +523,31 @@ get_closure (EDataBookView *book_view)
 static gpointer
 book_view_thread (gpointer data)
 {
-	EDataBookView *book_view = data;
-	FileBackendSearchClosure *closure = get_closure (book_view);
-	EBookBackendFile *bf = closure->bf;
+	EDataBookView *book_view;
+	FileBackendSearchClosure *closure;
+	EBookBackendFile *bf;
 	const char *query;
 	DB  *db;
 	DBT id_dbt, vcard_dbt;
 	int db_error;
-	gboolean stopped = FALSE, allcontacts;
+	gboolean allcontacts;
+
+	g_return_val_if_fail (E_IS_DATA_BOOK_VIEW (data), NULL);
+
+	book_view = data;
+	closure = get_closure (book_view);
+	if (!closure) {
+		g_warning (G_STRLOC ": NULL closure in book view thread");
+		return NULL;
+	}
+	bf = closure->bf;
 
 	d(printf ("starting initial population of book view\n"));
 
 	/* ref the book view because it'll be removed and unrefed
 	   when/if it's stopped */
 	bonobo_object_ref (book_view);
-	
+
 	db = bf->priv->file_db;
 	query = e_data_book_view_get_card_query (book_view);
 
@@ -565,9 +560,7 @@ book_view_thread (gpointer data)
 	}
 
 	d(printf ("signalling parent thread\n"));
-	g_mutex_lock (closure->mutex);
-	g_cond_signal (closure->cond);
-	g_mutex_unlock (closure->mutex);
+	e_flag_set (closure->running);
 
 	if (e_book_backend_summary_is_summary_query (bf->priv->summary, query)) {
 		/* do a summary query */
@@ -576,11 +569,8 @@ book_view_thread (gpointer data)
 
 		for (i = 0; i < ids->len; i ++) {
 			char *id = g_ptr_array_index (ids, i);
-			g_mutex_lock (closure->mutex);
-			stopped = closure->stopped;
-			g_mutex_unlock (closure->mutex);
 
-			if (stopped)
+			if (!e_flag_is_set (closure->running))
 				break;
 
 			string_to_dbt (id, &id_dbt);
@@ -613,11 +603,7 @@ book_view_thread (gpointer data)
 			db_error = dbc->c_get(dbc, &id_dbt, &vcard_dbt, DB_FIRST);
 			while (db_error == 0) {
 
-				g_mutex_lock (closure->mutex);
-				stopped = closure->stopped;
-				g_mutex_unlock (closure->mutex);
-
-				if (stopped)
+				if (!e_flag_is_set (closure->running))
 					break;
 
 				/* don't include the version in the list of cards */
@@ -647,7 +633,7 @@ book_view_thread (gpointer data)
 
 	}
 
-	if (!stopped)
+	if (e_flag_is_set (closure->running))
 		e_data_book_view_notify_complete (book_view, GNOME_Evolution_Addressbook_Success);
 
 	/* unref the */
@@ -665,15 +651,12 @@ e_book_backend_file_start_book_view (EBookBackend  *backend,
 {
 	FileBackendSearchClosure *closure = init_closure (book_view, E_BOOK_BACKEND_FILE (backend));
 
-	g_mutex_lock (closure->mutex);
-
 	d(printf ("starting book view thread\n"));
 	closure->thread = g_thread_create (book_view_thread, book_view, TRUE, NULL);
 
-	g_cond_wait (closure->cond, closure->mutex);
+	e_flag_wait (closure->running);
 
 	/* at this point we know the book view thread is actually running */
-	g_mutex_unlock (closure->mutex);
 	d(printf ("returning from start_book_view\n"));
 }
 
@@ -682,14 +665,14 @@ e_book_backend_file_stop_book_view (EBookBackend  *backend,
 				    EDataBookView *book_view)
 {
 	FileBackendSearchClosure *closure = get_closure (book_view);
-	gboolean need_join = FALSE;
+	gboolean need_join;
+
+	if (!closure)
+		return;
 
 	d(printf ("stopping query\n"));
-	g_mutex_lock (closure->mutex);
-	if (!closure->stopped)
-		need_join = TRUE;
-	closure->stopped = TRUE;
-	g_mutex_unlock (closure->mutex);
+	need_join = e_flag_is_set (closure->running);
+	e_flag_clear (closure->running);
 
 	if (need_join)
 		g_thread_join (closure->thread);
@@ -713,13 +696,13 @@ e_book_backend_file_changes_foreach_key (const char *key, gpointer user_data)
 	DB      *db = ctx->db;
 	DBT     id_dbt, vcard_dbt;
 	int     db_error = 0;
-	
+
 	string_to_dbt (key, &id_dbt);
 	memset (&vcard_dbt, 0, sizeof (vcard_dbt));
 	vcard_dbt.flags = DB_DBT_MALLOC;
 
 	db_error = db->get (db, NULL, &id_dbt, &vcard_dbt, 0);
-	
+
 	if (db_error != 0) {
 		EContact *contact;
 		char *id = id_dbt.data;
@@ -727,7 +710,7 @@ e_book_backend_file_changes_foreach_key (const char *key, gpointer user_data)
 
 		contact = e_contact_new ();
 		e_contact_set (contact, E_CONTACT_UID, id);
-		
+
 		vcard_string = e_vcard_to_string (E_VCARD (contact), EVC_FORMAT_VCARD_30);
 
 		ctx->del_ids = g_list_append (ctx->del_ids,
@@ -736,8 +719,9 @@ e_book_backend_file_changes_foreach_key (const char *key, gpointer user_data)
 						vcard_string);
 
 		g_object_unref (contact);
+
+		g_free (vcard_dbt.data);
 	}
-	g_free (vcard_dbt.data);
 }
 
 static EBookBackendSyncStatus
@@ -786,10 +770,10 @@ e_book_backend_file_get_changes (EBookBackendSync *backend,
 				EContact *contact;
 				char *id = id_dbt.data;
 				char *vcard_string;
-				
+
 				/* Remove fields the user can't change
 				 * and can change without the rest of the
-				 * card changing 
+				 * card changing
 				 */
 				contact = create_contact (id_dbt.data, vcard_dbt.data);
 
@@ -798,7 +782,7 @@ e_book_backend_file_get_changes (EBookBackendSync *backend,
 #endif
 				vcard_string = e_vcard_to_string (E_VCARD (contact), EVC_FORMAT_VCARD_30);
 				g_object_unref (contact);
-				
+
 				/* check what type of change has occurred, if any */
 				switch (e_dbhash_compare (ehash, id, vcard_string)) {
 				case E_DBHASH_STATUS_SAME:
@@ -840,7 +824,7 @@ e_book_backend_file_get_changes (EBookBackendSync *backend,
 
 			g_free (i->data);
 			g_free (v->data);
-		}	
+		}
 		for (i = ctx.mod_ids, v = ctx.mod_cards; i != NULL; i = i->next, v = v->next){
 			char *id = i->data;
 			char *vcard = v->data;
@@ -850,14 +834,14 @@ e_book_backend_file_get_changes (EBookBackendSync *backend,
 						  e_book_backend_change_modify_new (vcard));
 
 			g_free (i->data);
-			g_free (v->data);		
+			g_free (v->data);
 		}
-		for (i = ctx.del_ids, v = ctx.del_cards; i != NULL; i = i->next, v = v->next){	
+		for (i = ctx.del_ids, v = ctx.del_cards; i != NULL; i = i->next, v = v->next){
 			char *id = i->data;
 			char *vcard = v->data;
-			
+
 			e_dbhash_remove (ehash, id);
-			
+
 			changes = g_list_prepend (changes,
 						  e_book_backend_change_delete_new (vcard));
 			g_free (i->data);
@@ -901,7 +885,7 @@ e_book_backend_file_get_required_fields (EBookBackendSync *backend,
 					  GList **fields_out)
 {
 	GList *fields = NULL;
-	
+
 	fields = g_list_append (fields , g_strdup(e_contact_field_name (E_CONTACT_FILE_AS)));
 	*fields_out = fields;
 	return GNOME_Evolution_Addressbook_Success;
@@ -944,7 +928,7 @@ e_book_backend_file_upgrade_db (EBookBackendFile *bf, char *old_version)
 	DB  *db = bf->priv->file_db;
 	int db_error;
 	DBT version_name_dbt, version_dbt;
-	
+
 	if (strcmp (old_version, "0.0")
 	    && strcmp (old_version, "0.1")) {
 		g_warning ("unsupported version '%s' found in PAS backend file\n",
@@ -1097,7 +1081,7 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		return db_error_to_status (db_error);
 	}
 
-	g_static_mutex_lock(&global_env_lock);
+	G_LOCK (global_env);
 	if (global_env.ref_count > 0) {
 		env = global_env.env;
 		global_env.ref_count++;
@@ -1105,22 +1089,7 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		db_error = db_env_create (&env, 0);
 		if (db_error != 0) {
 			g_warning ("db_env_create failed with %s", db_strerror (db_error));
-			g_static_mutex_unlock(&global_env_lock);
-			g_free (dirname);
-			g_free (filename);
-			return db_error_to_status (db_error);
-		}
-
-		/* Set the allocation routines to the non-aborting GLib functions */
-		env->set_alloc (env, (void *(*)(size_t))g_try_malloc, 
-				(void *(*)(void *, size_t))g_try_realloc,
-				g_free);
-
-		db_error = env->open (env, NULL, DB_CREATE | DB_INIT_MPOOL | DB_PRIVATE | DB_THREAD, 0);
-		if (db_error != 0) {
-			env->close(env, 0);
-			g_warning ("db_env_open failed with %s", db_strerror (db_error));
-			g_static_mutex_unlock(&global_env_lock);
+			G_UNLOCK (global_env);
 			g_free (dirname);
 			g_free (filename);
 			return db_error_to_status (db_error);
@@ -1128,10 +1097,25 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 
 		env->set_errcall (env, file_errcall);
 
+		/* Set the allocation routines to the non-aborting GLib functions */
+		env->set_alloc (env, (void *(*)(size_t))g_try_malloc,
+				(void *(*)(void *, size_t))g_try_realloc,
+				g_free);
+
+		db_error = (*env->open) (env, NULL, DB_CREATE | DB_INIT_MPOOL | DB_PRIVATE | DB_THREAD, 0);
+		if (db_error != 0) {
+			env->close(env, 0);
+			g_warning ("db_env_open failed with %s", db_strerror (db_error));
+			G_UNLOCK (global_env);
+			g_free (dirname);
+			g_free (filename);
+			return db_error_to_status (db_error);
+		}
+
 		global_env.env = env;
 		global_env.ref_count = 1;
 	}
-	g_static_mutex_unlock(&global_env_lock);
+	G_UNLOCK (global_env);
 
 	bf->priv->env = env;
 
@@ -1143,7 +1127,7 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		return db_error_to_status (db_error);
 	}
 
-	db_error = db->open (db, NULL, filename, NULL, DB_HASH, DB_THREAD, 0666);
+	db_error = (*db->open) (db, NULL, filename, NULL, DB_HASH, DB_THREAD, 0666);
 
 	if (db_error == DB_OLD_VERSION) {
 		db_error = e_db3_utils_upgrade_format (filename);
@@ -1155,24 +1139,31 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 			return db_error_to_status (db_error);
 		}
 
-		db_error = db->open (db, NULL, filename, NULL, DB_HASH, DB_THREAD, 0666);
-	}
+		db->close (db, 0);
+		db_error = db_create (&db, env, 0);
+		if (db_error != 0) {
+			g_warning ("db_create failed with %s", db_strerror (db_error));
+			g_free (dirname);
+			g_free (filename);
+			return db_error_to_status (db_error);
+		}
 
-	bf->priv->file_db = db;
+		db_error = (*db->open) (db, NULL, filename, NULL, DB_HASH, DB_THREAD, 0666);
+	}
 
 	if (db_error == 0) {
 		writable = TRUE;
 	} else {
 		db->close (db, 0);
-		
         	db_error = db_create (&db, env, 0);
         	if (db_error != 0) {
                 	g_warning ("db_create failed with %s", db_strerror (db_error));
                 	g_free (dirname);
                 	g_free (filename);
-                	return GNOME_Evolution_Addressbook_OtherError;
+                	return db_error_to_status (db_error);
         	}
-		db_error = db->open (db, NULL, filename, NULL, DB_HASH, DB_RDONLY | DB_THREAD, 0666);
+
+		db_error = (*db->open) (db, NULL, filename, NULL, DB_HASH, DB_RDONLY | DB_THREAD, 0666);
 
 		if (db_error != 0 && !only_if_exists) {
 			int rv;
@@ -1196,10 +1187,10 @@ e_book_backend_file_load_source (EBookBackend           *backend,
  				g_warning ("db_create failed with %s", db_strerror (db_error));
 				g_free (dirname);
 				g_free (filename);
-				return GNOME_Evolution_Addressbook_OtherError;
+				return db_error_to_status (db_error);
 			}
 
-			db_error = db->open (db, NULL, filename, NULL, DB_HASH, DB_CREATE | DB_THREAD, 0666);
+			db_error = (*db->open) (db, NULL, filename, NULL, DB_HASH, DB_CREATE | DB_THREAD, 0666);
 			if (db_error != 0) {
 				db->close (db, 0);
 				g_warning ("db->open (... DB_CREATE ...) failed with %s", db_strerror (db_error));
@@ -1207,9 +1198,11 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 			else {
 #ifdef CREATE_DEFAULT_VCARD
 				EContact *contact = NULL;
+				EBookBackendSyncStatus status;
 
-				do_create(bf, XIMIAN_VCARD, &contact);
-				/* XXX check errors here */
+				status = do_create (bf, XIMIAN_VCARD, &contact);
+				if (status != GNOME_Evolution_Addressbook_Success)
+					g_warning ("Cannot create default contact: %d", status);
 				if (contact)
 					g_object_unref (contact);
 #endif
@@ -1219,6 +1212,8 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		}
 	}
 
+	bf->priv->file_db = db;
+
 	if (db_error != 0) {
 		bf->priv->file_db = NULL;
 		g_free (dirname);
@@ -1340,7 +1335,7 @@ e_book_backend_file_cancel_operation (EBookBackend *backend, EDataBook *book)
 {
 	return GNOME_Evolution_Addressbook_CouldNotCancel;
 }
-static void 
+static void
 e_book_backend_file_set_mode (EBookBackend *backend,  GNOME_Evolution_Addressbook_BookMode mode)
 {
 	if (e_book_backend_is_loaded (backend)) {
@@ -1349,18 +1344,18 @@ e_book_backend_file_set_mode (EBookBackend *backend,  GNOME_Evolution_Addressboo
 	}
 }
 
-static void 
+static void
 e_book_backend_file_sync (EBookBackend *backend)
 {
 	EBookBackendFile *bf = E_BOOK_BACKEND_FILE (backend);
 	int db_error;
-	
+
 	g_return_if_fail (bf != NULL);
-	
+
 	if (bf->priv->file_db) {
 		db_error = bf->priv->file_db->sync (bf->priv->file_db, 0);
 		if (db_error != 0)
-			g_warning ("db->sync failed with %d", db_error);
+			g_warning (G_STRLOC ": db->sync failed with %s", db_strerror (db_error));
 	}
 }
 
@@ -1406,21 +1401,21 @@ e_book_backend_file_dispose (GObject *object)
 		bf->priv->file_db->close (bf->priv->file_db, 0);
 		bf->priv->file_db = NULL;
 	}
-	
-	g_static_mutex_lock(&global_env_lock);
+
+	G_LOCK (global_env);
 	global_env.ref_count--;
 	if (global_env.ref_count == 0) {
 		global_env.env->close (global_env.env, 0);
 		global_env.env = NULL;
 	}
-	g_static_mutex_unlock (&global_env_lock);
-	
+	G_UNLOCK (global_env);
+
 	if (bf->priv->summary) {
 		g_object_unref (bf->priv->summary);
 		bf->priv->summary = NULL;
 	}
 
-	G_OBJECT_CLASS (e_book_backend_file_parent_class)->dispose (object);	
+	G_OBJECT_CLASS (e_book_backend_file_parent_class)->dispose (object);
 }
 
 static void
@@ -1433,7 +1428,7 @@ e_book_backend_file_finalize (GObject *object)
 	g_free (bf->priv->filename);
 	g_free (bf->priv->dirname);
 	g_free (bf->priv->summary_filename);
-	
+
 	g_free (bf->priv);
 
 	G_OBJECT_CLASS (e_book_backend_file_parent_class)->finalize (object);
@@ -1490,8 +1485,6 @@ e_book_backend_file_class_init (EBookBackendFileClass *klass)
 	EBookBackendSyncClass *sync_class;
 	EBookBackendClass *backend_class;
 
-	e_book_backend_file_parent_class = g_type_class_peek_parent (klass);
-
 	sync_class = E_BOOK_BACKEND_SYNC_CLASS (klass);
 	backend_class = E_BOOK_BACKEND_CLASS (klass);
 
@@ -1502,7 +1495,7 @@ e_book_backend_file_class_init (EBookBackendFileClass *klass)
 	backend_class->stop_book_view          = e_book_backend_file_stop_book_view;
 	backend_class->cancel_operation        = e_book_backend_file_cancel_operation;
 	backend_class->set_mode                = e_book_backend_file_set_mode;
-	backend_class->sync                = e_book_backend_file_sync;
+	backend_class->sync                    = e_book_backend_file_sync;
 	sync_class->remove_sync                = e_book_backend_file_remove;
 	sync_class->create_contact_sync        = e_book_backend_file_create_contact;
 	sync_class->remove_contacts_sync       = e_book_backend_file_remove_contacts;
@@ -1513,7 +1506,7 @@ e_book_backend_file_class_init (EBookBackendFileClass *klass)
 	sync_class->authenticate_user_sync     = e_book_backend_file_authenticate_user;
 	sync_class->get_supported_fields_sync  = e_book_backend_file_get_supported_fields;
 	sync_class->get_required_fields_sync   = e_book_backend_file_get_required_fields;
-	
+
 
 	object_class->dispose = e_book_backend_file_dispose;
 	object_class->finalize = e_book_backend_file_finalize;
@@ -1539,30 +1532,3 @@ e_book_backend_file_init (EBookBackendFile *backend)
 
 	backend->priv = priv;
 }
-
-/**
- * e_book_backend_file_get_type:
- */
-GType
-e_book_backend_file_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo info = {
-			sizeof (EBookBackendFileClass),
-			NULL, /* base_class_init */
-			NULL, /* base_class_finalize */
-			(GClassInitFunc)  e_book_backend_file_class_init,
-			NULL, /* class_finalize */
-			NULL, /* class_data */
-			sizeof (EBookBackendFile),
-			0,    /* n_preallocs */
-			(GInstanceInitFunc) e_book_backend_file_init
-		};
-
-		type = g_type_register_static (E_TYPE_BOOK_BACKEND_SYNC, "EBookBackendFile", &info, 0);
-	}
-
-	return type;
-}
