@@ -292,6 +292,7 @@ entry_compare(SearchContext *ctx, struct _ESExp *f,
 		struct prop_info *info = NULL;
 		int i;
 		gboolean any_field;
+		gboolean saw_any = FALSE;
 
 		propname = argv[0]->value.string;
 
@@ -299,6 +300,7 @@ entry_compare(SearchContext *ctx, struct _ESExp *f,
 		for (i = 0; i < G_N_ELEMENTS (prop_info_table); i ++) {
 			if (any_field
 			    || !strcmp (prop_info_table[i].query_prop, propname)) {
+				saw_any = TRUE;
 				info = &prop_info_table[i];
 
 				if (any_field && info->field_id == E_CONTACT_UID) {
@@ -335,6 +337,39 @@ entry_compare(SearchContext *ctx, struct _ESExp *f,
 			}
 		}
 
+		if (!saw_any) {
+			/* propname didn't match to any of our known "special" properties,
+			   so try to find if it isn't a real field and if so, then compare
+			   against value in this field only */
+			EContactField fid = e_contact_field_id (propname);
+
+			if (fid >= E_CONTACT_FIELD_FIRST && fid < E_CONTACT_FIELD_LAST) {
+				const char *prop = e_contact_get_const (ctx->contact, fid);
+
+				if (prop && compare (prop, argv[1]->value.string)) {
+					truth = TRUE;
+				}
+
+				if ((!prop) && compare ("", argv[1]->value.string)) {
+					truth = TRUE;
+				}
+			} else {
+				/* it is not direct EContact known field, so try to find
+				   it in EVCard attributes */
+				EVCardAttribute *attr = e_vcard_get_attribute (E_VCARD (ctx->contact), propname);
+				GList *l, *values = attr ? e_vcard_attribute_get_values (attr) : NULL;
+
+				for (l = values; l && !truth; l = l->next) {
+					const char *value = l->data;
+
+					if (value && compare (value, argv[1]->value.string)) {
+						truth = TRUE;
+					} else if ((!value) && compare ("", argv[1]->value.string)) {
+						truth = TRUE;
+					}
+				}
+			}
+		}
 	}
 	r = e_sexp_result_new(f, ESEXP_RES_BOOL);
 	r->value.bool = truth;
@@ -342,12 +377,168 @@ entry_compare(SearchContext *ctx, struct _ESExp *f,
 	return r;
 }
 
+static void
+contains_helper_free_word (gpointer data, gpointer user_data)
+{
+	if (data){
+		g_string_free ((GString *)data, TRUE);
+	}
+}
+
+static char *
+try_contains_word (const gchar *s1, GSList *word)
+{
+	const gchar *o, *p;
+	gunichar unival, first_w_char;
+	GString *w;
+
+	if (s1 == NULL) return NULL;
+	if (word == NULL) return (char*)s1; /* previous was last word */
+	if (word->data == NULL) return NULL; /* illegal structure */
+
+	w = word->data;
+	first_w_char = g_utf8_get_char (w->str);
+
+	o  = s1;
+	for (p = e_util_unicode_get_utf8 (o, &unival); p && unival; p = e_util_unicode_get_utf8 (p, &unival)) {
+		if (unival == first_w_char) {
+			gunichar unival2;
+			const gchar *q = p;
+			const gchar *r = e_util_unicode_get_utf8 (w->str, &unival2);
+			while (q && r && unival && unival2) {
+				q = e_util_unicode_get_utf8 (q, &unival);
+				if (!q) break;
+				r = e_util_unicode_get_utf8 (r, &unival2);
+				if (!r) break;
+				if (unival != unival2) break;
+			}
+			if (!unival2 && r && q) {
+				/* we read whole word and no illegal character has been found */
+				if (word->next == NULL ||
+				    try_contains_word ( e_util_unicode_get_utf8 (o, &unival), word->next)){
+					return (char*)o;
+				}
+			}
+		}
+		o = p;
+	}
+
+	return NULL;
+}
+
+/* converts str into utf8 GString in lowercase;
+   returns NULL if str is invalid utf8 string otherwise
+   returns newly allocated GString
+*/
+static GString *
+chars_to_unistring_lowercase (const char *str)
+{
+	GString *res;
+	gunichar unich;
+	gchar *p;
+
+	if (str == NULL) return NULL;
+
+	res = g_string_new ("");
+
+	for (p = e_util_unicode_get_utf8 (str,&unich); p && unich; p = e_util_unicode_get_utf8 (p,&unich)){
+		g_string_append_unichar (res, g_unichar_tolower (unich));
+	}
+
+	/* it was invalid unichar string */
+	if (p == NULL){
+		g_string_free (res, TRUE);
+		return NULL;
+	}
+
+	return res;
+}
+
+/* first space between words is treated as wildcard character;
+   we are looking for s2 in s1, so s2 will be breaked into words
+*/
+static char *
+contains_helper (const char *s1, const char *s2)
+{
+	GString *s1uni;
+	GString *s2uni;
+	GSList *words;
+	char *next;
+	gboolean have_nonspace;
+	gboolean have_space;
+	GString *last_word, *w;
+	char *res = NULL;
+	gunichar unich;
+
+	s1uni = chars_to_unistring_lowercase (s1);
+	if (s1 == NULL) return NULL;
+
+	s2uni = chars_to_unistring_lowercase (s2);
+	if (s2 == NULL){
+		g_string_free (s1uni, TRUE);
+		return NULL;
+	}
+
+	if (g_utf8_strlen (s1uni->str, -1) == 0 ||
+	    g_utf8_strlen (s2uni->str, -1) == 0){
+		g_string_free (s1uni, TRUE);
+		g_string_free (s2uni, TRUE);
+		return NULL;
+	}
+
+	/* breaking s2 into words */
+        words = NULL;
+	have_nonspace = FALSE;
+	have_space = FALSE;
+	last_word = NULL;
+	w = g_string_new ("");
+	for (next = e_util_unicode_get_utf8 (s2uni->str, &unich); next && unich; next = e_util_unicode_get_utf8 (next, &unich) ){
+		if (unich == ' '){
+			if (have_nonspace && !have_space){
+				/* treat only first space after nonspace character as wildcard,
+				   so we will start new word here
+				*/
+				have_space = TRUE;
+				words = g_slist_append (words, w);
+				last_word = w;
+				w = g_string_new ("");
+			}else{
+				g_string_append_unichar (w, unich);
+			}
+		}else{
+			have_nonspace = TRUE;
+			have_space = FALSE;
+			g_string_append_unichar (w, unich);
+		}
+	}
+
+	if (have_space){
+		/* there was one or more spaces at the end of string,
+		   concat actual word with that last one
+		*/
+		g_string_append_len (last_word, w->str, w->len);
+		g_string_free (w, TRUE);
+	}else{
+		/* append actual word into words list */
+		words = g_slist_append (words, w);
+	}
+
+	res = try_contains_word (s1uni->str, words);
+
+	g_string_free (s1uni, TRUE);
+	g_string_free (s2uni, TRUE);
+	g_slist_foreach (words, contains_helper_free_word, NULL);
+	g_slist_free (words);
+
+	return res;
+}
+
 static ESExpResult *
 func_contains(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 {
 	SearchContext *ctx = data;
 
-	return entry_compare (ctx, f, argc, argv, (char *(*)(const char*, const char*)) e_util_utf8_strstrcase);
+	return entry_compare (ctx, f, argc, argv, contains_helper);
 }
 
 static char *
@@ -370,12 +561,13 @@ func_is(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 static char *
 endswith_helper (const char *s1, const char *s2)
 {
-	char *p;
-	if ((p = (char*) e_util_utf8_strstrcase(s1, s2))
-	    && (strlen(p) == strlen(s2)))
-		return p;
-	else
+	glong s1len = g_utf8_strlen (s1, -1);
+	glong s2len = g_utf8_strlen (s2, -1);
+
+	if (s1len < s2len)
 		return NULL;
+
+	return (char *)e_util_utf8_strstrcase (g_utf8_offset_to_pointer (s1, s1len - s2len), s2);
 }
 
 static ESExpResult *
@@ -417,11 +609,13 @@ func_exists(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 		char *propname;
 		struct prop_info *info = NULL;
 		int i;
+		gboolean saw_any = FALSE;
 
 		propname = argv[0]->value.string;
 
 		for (i = 0; i < G_N_ELEMENTS (prop_info_table); i ++) {
 			if (!strcmp (prop_info_table[i].query_prop, propname)) {
+				saw_any = TRUE;
 				info = &prop_info_table[i];
 
 				if (info->prop_type == PROP_TYPE_NORMAL) {
@@ -443,6 +637,30 @@ func_exists(struct _ESExp *f, int argc, struct _ESExpResult **argv, void *data)
 			}
 		}
 
+		if (!saw_any) {
+			/* propname didn't match to any of our known "special" properties,
+			   so try to find if it isn't a real field and if so, then check
+			   against value in this field only */
+			EContactField fid = e_contact_field_id (propname);
+
+			if (fid >= E_CONTACT_FIELD_FIRST && fid < E_CONTACT_FIELD_LAST) {
+				const char *prop = e_contact_get_const (ctx->contact, fid);
+
+				if (prop && *prop)
+					truth = TRUE;
+			} else {
+				/* is is not a known EContact field, try with EVCard attributes */
+				EVCardAttribute *attr = e_vcard_get_attribute (E_VCARD (ctx->contact), propname);
+				GList *l, *values = attr ? e_vcard_attribute_get_values (attr) : NULL;
+
+				for (l = values; l && !truth; l = l->next) {
+					const char *value = l->data;
+
+					if (value && *value)
+						truth = TRUE;
+				}
+			}
+		}
 	}
 	r = e_sexp_result_new(f, ESEXP_RES_BOOL);
 	r->value.bool = truth;
