@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef E_DATA_CAL_VIEW_H
@@ -49,6 +49,9 @@ struct _EDataCalViewClass {
 	BonoboObjectClass parent_class;
 
 	POA_GNOME_Evolution_Calendar_CalView__epv epv;
+
+	/* Notification signals */
+	void (* last_listener_gone) (EDataCalView *query);
 };
 
 GType                 e_data_cal_view_get_type (void);
@@ -74,9 +77,9 @@ void                  e_data_cal_view_notify_objects_modified (EDataCalView
 void                  e_data_cal_view_notify_objects_modified_1 (EDataCalView       *query,
 								 const char *object);
 void                  e_data_cal_view_notify_objects_removed (EDataCalView       *query,
-							      const GList *uids);
+							      const GList *ids);
 void                  e_data_cal_view_notify_objects_removed_1 (EDataCalView       *query,
-								const char *uid);
+								const ECalComponentId *id);
 void                  e_data_cal_view_notify_progress (EDataCalView      *query,
 						       const char *message,
 						       int         percent);
