@@ -43,7 +43,7 @@
 #include "camel-tcp-stream-ssl.h"
 #endif
 
-#define d(x)
+#define d(x) 
 
 static CamelStreamClass *parent_class = NULL;
 
@@ -58,9 +58,9 @@ camel_http_stream_class_init (CamelHttpStreamClass *camel_http_stream_class)
 {
 	CamelStreamClass *camel_stream_class =
 		CAMEL_STREAM_CLASS (camel_http_stream_class);
-
+	
 	parent_class = CAMEL_STREAM_CLASS (camel_type_get_global_classfuncs (camel_stream_get_type ()));
-
+	
 	/* virtual method overload */
 	camel_stream_class->read = stream_read;
 	camel_stream_class->write = stream_write;
@@ -73,7 +73,7 @@ static void
 camel_http_stream_init (gpointer object, gpointer klass)
 {
 	CamelHttpStream *http = CAMEL_HTTP_STREAM (object);
-
+	
 	http->parser = NULL;
 	http->content_type = NULL;
 	http->headers = NULL;
@@ -90,28 +90,28 @@ static void
 camel_http_stream_finalize (CamelObject *object)
 {
 	CamelHttpStream *http = CAMEL_HTTP_STREAM (object);
-
+	
 	if (http->parser)
 		camel_object_unref(http->parser);
-
+	
 	if (http->content_type)
 		camel_content_type_unref (http->content_type);
-
+	
 	if (http->headers)
 		camel_header_raw_clear (&http->headers);
-
+	
 	if (http->session)
 		camel_object_unref(http->session);
-
+	
 	if (http->url)
 		camel_url_free (http->url);
-
+	
 	if (http->proxy)
 		camel_url_free (http->proxy);
-
+	
 	g_free (http->authrealm);
 	g_free (http->authpass);
-
+	
 	if (http->raw)
 		camel_object_unref(http->raw);
 	if (http->read)
@@ -122,7 +122,7 @@ CamelType
 camel_http_stream_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-
+	
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_stream_get_type (),
 					    "CamelHttpStream",
@@ -133,7 +133,7 @@ camel_http_stream_get_type (void)
 					    (CamelObjectInitFunc) camel_http_stream_init,
 					    (CamelObjectFinalizeFunc) camel_http_stream_finalize);
 	}
-
+	
 	return type;
 }
 
@@ -150,20 +150,20 @@ camel_http_stream_new (CamelHttpMethod method, struct _CamelSession *session, Ca
 {
 	CamelHttpStream *stream;
 	char *str;
-
+	
 	g_return_val_if_fail(CAMEL_IS_SESSION(session), NULL);
 	g_return_val_if_fail(url != NULL, NULL);
-
+	
 	stream = CAMEL_HTTP_STREAM (camel_object_new (camel_http_stream_get_type ()));
-
+	
 	stream->method = method;
 	stream->session = session;
 	camel_object_ref(session);
-
+	
 	str = camel_url_to_string (url, 0);
 	stream->url = camel_url_new (str, NULL);
 	g_free (str);
-
+	
 	return (CamelStream *)stream;
 }
 
@@ -186,7 +186,7 @@ http_connect (CamelHttpStream *http, CamelURL *url)
 	} else {
 		stream = camel_tcp_stream_raw_new ();
 	}
-
+	
 	if (stream == NULL) {
 		errno = EINVAL;
 		return NULL;
@@ -205,7 +205,7 @@ http_connect (CamelHttpStream *http, CamelURL *url)
 		camel_object_unref (stream);
 		return NULL;
 	}
-
+	
 	if (camel_tcp_stream_connect (CAMEL_TCP_STREAM (stream), ai) == -1) {
 		errsave = errno;
 		camel_object_unref (stream);
@@ -213,12 +213,12 @@ http_connect (CamelHttpStream *http, CamelURL *url)
 		errno = errsave;
 		return NULL;
 	}
-
+	
 	camel_freeaddrinfo(ai);
 
 	http->raw = stream;
 	http->read = camel_stream_buffer_new (stream, CAMEL_STREAM_BUFFER_READ);
-
+	
 	return stream;
 }
 
@@ -229,7 +229,7 @@ http_disconnect(CamelHttpStream *http)
 		camel_object_unref(http->raw);
 		http->raw = NULL;
 	}
-
+			
 	if (http->read) {
 		camel_object_unref(http->read);
 		http->read = NULL;
@@ -245,13 +245,13 @@ static const char *
 http_next_token (const unsigned char *in)
 {
 	const unsigned char *inptr = in;
-
+	
 	while (*inptr && !isspace ((int) *inptr))
 		inptr++;
-
+	
 	while (*inptr && isspace ((int) *inptr))
 		inptr++;
-
+	
 	return (const char *) inptr;
 }
 
@@ -260,7 +260,7 @@ http_get_statuscode (CamelHttpStream *http)
 {
 	const char *token;
 	char buffer[4096];
-
+	
 	if (camel_stream_buffer_gets ((CamelStreamBuffer *)http->read, buffer, sizeof (buffer)) <= 0)
 		return -1;
 
@@ -274,7 +274,7 @@ http_get_statuscode (CamelHttpStream *http)
 	}
 
 	http_disconnect(http);
-
+	
 	return -1;
 }
 
@@ -286,13 +286,13 @@ http_get_headers (CamelHttpStream *http)
 	char *buf;
 	size_t len;
 	int err;
-
+	
 	if (http->parser)
 		camel_object_unref (http->parser);
-
+	
 	http->parser = camel_mime_parser_new ();
 	camel_mime_parser_init_with_stream (http->parser, http->read);
-
+	
 	switch (camel_mime_parser_step (http->parser, &buf, &len)) {
 	case CAMEL_MIME_PARSER_STATE_MESSAGE:
 	case CAMEL_MIME_PARSER_STATE_HEADER:
@@ -304,13 +304,13 @@ http_get_headers (CamelHttpStream *http)
 			http->content_type = camel_content_type_decode (type);
 		else
 			http->content_type = NULL;
-
+		
 		if (http->headers)
 			camel_header_raw_clear (&http->headers);
-
+		
 		http->headers = NULL;
 		tail = (struct _camel_header_raw *) &http->headers;
-
+		
 		d(printf("HTTP Headers:\n"));
 		while (headers) {
 			d(printf(" %s:%s\n", headers->name, headers->value));
@@ -323,27 +323,27 @@ http_get_headers (CamelHttpStream *http)
 			tail = node;
 			headers = headers->next;
 		}
-
+		
 		break;
 	default:
 		g_warning ("Invalid state encountered???: %u", camel_mime_parser_state (http->parser));
 	}
-
+	
 	err = camel_mime_parser_errno (http->parser);
-
+	
 	if (err != 0) {
 		camel_object_unref (http->parser);
 		http->parser = NULL;
 		goto exception;
 	}
-
+	
 	camel_mime_parser_drop_step (http->parser);
-
+	
 	return 0;
-
+	
  exception:
 	http_disconnect(http);
-
+	
 	return -1;
 }
 
@@ -352,7 +352,7 @@ http_method_invoke (CamelHttpStream *http)
 {
 	const char *method = NULL;
 	char *url;
-
+	
 	switch (http->method) {
 	case CAMEL_HTTP_METHOD_GET:
 		method = "GET";
@@ -363,7 +363,7 @@ http_method_invoke (CamelHttpStream *http)
 	default:
 		g_assert_not_reached ();
 	}
-
+	
 	url = camel_url_to_string (http->url, 0);
 	d(printf("HTTP Stream Sending: %s %s HTTP/1.0\r\nUser-Agent: %s\r\nHost: %s\r\n",
 		 method,
@@ -372,7 +372,7 @@ http_method_invoke (CamelHttpStream *http)
 		 http->url->host));
 	if (camel_stream_printf (http->raw, "%s %s HTTP/1.0\r\nUser-Agent: %s\r\nHost: %s\r\n",
 				 method,
-				 url,
+				 http->proxy ? url : http->url->path,
 				 http->user_agent ? http->user_agent : "CamelHttpStream/1.0",
 				 http->url->host) == -1) {
 		http_disconnect(http);
@@ -383,7 +383,7 @@ http_method_invoke (CamelHttpStream *http)
 
 	if (http->authrealm)
 		d(printf("HTTP Stream Sending: WWW-Authenticate: %s\n", http->authrealm));
-
+	
 	if (http->authrealm && camel_stream_printf (http->raw, "WWW-Authenticate: %s\r\n", http->authrealm) == -1) {
 		http_disconnect(http);
 		return -1;
@@ -391,19 +391,19 @@ http_method_invoke (CamelHttpStream *http)
 
 	if (http->authpass && http->proxy)
 		d(printf("HTTP Stream Sending: Proxy-Aurhorization: Basic %s\n", http->authpass));
-
+	
 	if (http->authpass && http->proxy && camel_stream_printf (http->raw, "Proxy-Authorization: Basic %s\r\n",
 								  http->authpass) == -1) {
 		http_disconnect(http);
 		return -1;
 	}
-
+	
 	/* end the headers */
 	if (camel_stream_write (http->raw, "\r\n", 2) == -1 || camel_stream_flush (http->raw) == -1) {
 		http_disconnect(http);
 		return -1;
 	}
-
+	
 	return 0;
 }
 
@@ -413,27 +413,27 @@ stream_read (CamelStream *stream, char *buffer, size_t n)
 	CamelHttpStream *http = CAMEL_HTTP_STREAM (stream);
 	const char *parser_buf;
 	ssize_t nread;
-
+	
 	if (http->method != CAMEL_HTTP_METHOD_GET && http->method != CAMEL_HTTP_METHOD_HEAD) {
 		errno = EIO;
 		return -1;
 	}
-
+	
  redirect:
-
+	
 	if (!http->raw) {
 		if (http_connect (http, http->proxy ? http->proxy : http->url) == NULL)
 			return -1;
-
+		
 		if (http_method_invoke (http) == -1)
 			return -1;
-
+		
 		if (http_get_statuscode (http) == -1)
 			return -1;
-
+		
 		if (http_get_headers (http) == -1)
 			return -1;
-
+		
 		switch (http->statuscode) {
 		case 200:
 		case 206:
@@ -480,14 +480,14 @@ stream_read (CamelStream *stream, char *buffer, size_t n)
 			return -1;
 		}
 	}
-
+	
 	nread = camel_mime_parser_read (http->parser, &parser_buf, n);
-
+	
 	if (nread > 0)
 		memcpy (buffer, parser_buf, nread);
 	else if (nread == 0)
 		stream->eos = TRUE;
-
+	
 	return nread;
 }
 
@@ -501,7 +501,7 @@ static int
 stream_flush (CamelStream *stream)
 {
 	CamelHttpStream *http = (CamelHttpStream *) stream;
-
+	
 	if (http->raw)
 		return camel_stream_flush (http->raw);
 	else
@@ -512,14 +512,14 @@ static int
 stream_close (CamelStream *stream)
 {
 	CamelHttpStream *http = (CamelHttpStream *) stream;
-
+	
 	if (http->raw) {
 		if (camel_stream_close (http->raw) == -1)
 			return -1;
 
 		http_disconnect(http);
 	}
-
+	
 	return 0;
 }
 
@@ -527,7 +527,7 @@ static int
 stream_reset (CamelStream *stream)
 {
 	CamelHttpStream *http = CAMEL_HTTP_STREAM (stream);
-
+	
 	if (http->raw)
 		http_disconnect(http);
 
@@ -560,7 +560,7 @@ void
 camel_http_stream_set_user_agent (CamelHttpStream *http_stream, const char *user_agent)
 {
 	g_return_if_fail (CAMEL_IS_HTTP_STREAM (http_stream));
-
+	
 	g_free (http_stream->user_agent);
 	http_stream->user_agent = g_strdup (user_agent);
 }
@@ -569,7 +569,7 @@ void
 camel_http_stream_set_proxy (CamelHttpStream *http_stream, const char *proxy_url)
 {
 	g_return_if_fail (CAMEL_IS_HTTP_STREAM (http_stream));
-
+	
 	if (http_stream->proxy)
 		camel_url_free (http_stream->proxy);
 
@@ -598,7 +598,7 @@ void
 camel_http_stream_set_proxy_authrealm (CamelHttpStream *http_stream, const char *proxy_authrealm)
 {
 	g_return_if_fail (CAMEL_IS_HTTP_STREAM (http_stream));
-
+	
 	g_free (http_stream->authrealm);
 	http_stream->authrealm = g_strdup (proxy_authrealm);
 }
@@ -607,7 +607,7 @@ void
 camel_http_stream_set_proxy_authpass (CamelHttpStream *http_stream, const char *proxy_authpass)
 {
 	g_return_if_fail (CAMEL_IS_HTTP_STREAM (http_stream));
-
+	
 	g_free (http_stream->authpass);
 	http_stream->authpass = g_strdup (proxy_authpass);
 }
