@@ -43,7 +43,7 @@ enum {
 	GZIP_FLAG_FCOMMENT  = (1 << 4),
 	GZIP_FLAG_RESERVED0 = (1 << 5),
 	GZIP_FLAG_RESERVED1 = (1 << 6),
-	GZIP_FLAG_RESERVED2 = (1 << 7),
+	GZIP_FLAG_RESERVED2 = (1 << 7)
 };
 
 #define GZIP_FLAG_RESERVED (GZIP_FLAG_RESERVED0 | GZIP_FLAG_RESERVED1 | GZIP_FLAG_RESERVED2)
@@ -180,64 +180,64 @@ gzip_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 		else
 			priv->hdr.v.xfl = 0;
 		priv->hdr.v.os = 255;
-		
+
 		camel_mime_filter_set_size (filter, (len * 2) + 22, FALSE);
-		
+
 		memcpy (filter->outbuf, priv->hdr.buf, 10);
-		
-		priv->stream->next_out = filter->outbuf + 10;
+
+		priv->stream->next_out = (Bytef *) filter->outbuf + 10;
 		priv->stream->avail_out = filter->outsize - 10;
-		
+
 		priv->state.zip.wrote_hdr = TRUE;
 	} else {
 		camel_mime_filter_set_size (filter, (len * 2) + 12, FALSE);
-		
-		priv->stream->next_out = filter->outbuf;
+
+		priv->stream->next_out = (Bytef *) filter->outbuf;
 		priv->stream->avail_out = filter->outsize;
 	}
-	
-	priv->stream->next_in = in;
+
+	priv->stream->next_in = (Bytef *) in;
 	priv->stream->avail_in = len;
-	
+
 	do {
 		/* FIXME: handle error cases? */
 		if ((retval = deflate (priv->stream, flush)) != Z_OK)
 			fprintf (stderr, "gzip: %d: %s\n", retval, priv->stream->msg);
-		
+
 		if (flush == Z_FULL_FLUSH) {
 			size_t n;
-			
+
 			n = filter->outsize - priv->stream->avail_out;
 			camel_mime_filter_set_size (filter, n + (priv->stream->avail_in * 2) + 12, TRUE);
 			priv->stream->avail_out = filter->outsize - n;
-			priv->stream->next_out = filter->outbuf + n;
-			
+			priv->stream->next_out = (Bytef *) filter->outbuf + n;
+
 			if (priv->stream->avail_in == 0) {
 				guint32 val;
-				
+
 				val = GUINT32_TO_LE (priv->crc32);
 				memcpy (priv->stream->next_out, &val, 4);
 				priv->stream->avail_out -= 4;
 				priv->stream->next_out += 4;
-				
+
 				val = GUINT32_TO_LE (priv->isize);
 				memcpy (priv->stream->next_out, &val, 4);
 				priv->stream->avail_out -= 4;
 				priv->stream->next_out += 4;
-				
+
 				break;
 			}
 		} else {
 			if (priv->stream->avail_in > 0)
-				camel_mime_filter_backup (filter, priv->stream->next_in, priv->stream->avail_in);
-			
+				camel_mime_filter_backup (filter, (const char *) priv->stream->next_in, priv->stream->avail_in);
+
 			break;
 		}
 	} while (1);
-	
-	priv->crc32 = crc32 (priv->crc32, in, len - priv->stream->avail_in);
+
+	priv->crc32 = crc32 (priv->crc32, (unsigned char *) in, len - priv->stream->avail_in);
 	priv->isize += len - priv->stream->avail_in;
-	
+
 	*out = filter->outbuf;
 	*outlen = filter->outsize - priv->stream->avail_out;
 	*outprespace = filter->outpre;
@@ -328,63 +328,63 @@ gunzip_filter (CamelMimeFilter *filter, char *in, size_t len, size_t prespace,
 			return;
 		}
 	}
-	
+
 	if ((priv->hdr.v.flg & GZIP_FLAG_FHCRC) && !priv->state.unzip.got_crc16) {
 		if (len < 2) {
 			camel_mime_filter_backup (filter, in, len);
 			return;
 		}
-		
+
 		memcpy (&val, in, 2);
 		priv->state.unzip.crc16 = GUINT16_FROM_LE (val);
 		len -= 2;
 		in += 2;
 	}
-	
+
 	if (len == 0)
 		return;
-	
+
 	camel_mime_filter_set_size (filter, (len * 2) + 12, FALSE);
-	
-	priv->stream->next_in = in;
+
+	priv->stream->next_in = (Bytef *) in;
 	priv->stream->avail_in = len - 8;
-	
-	priv->stream->next_out = filter->outbuf;
+
+	priv->stream->next_out = (Bytef *) filter->outbuf;
 	priv->stream->avail_out = filter->outsize;
-	
+
 	do {
 		/* FIXME: handle error cases? */
 		if ((retval = inflate (priv->stream, flush)) != Z_OK)
 			fprintf (stderr, "gunzip: %d: %s\n", retval, priv->stream->msg);
-		
+
 		if (flush == Z_FULL_FLUSH) {
 			size_t n;
-			
+
 			if (priv->stream->avail_in == 0) {
 				/* FIXME: extract & compare calculated crc32 and isize values? */
 				break;
 			}
-			
+
 			n = filter->outsize - priv->stream->avail_out;
 			camel_mime_filter_set_size (filter, n + (priv->stream->avail_in * 2) + 12, TRUE);
 			priv->stream->avail_out = filter->outsize - n;
-			priv->stream->next_out = filter->outbuf + n;
+			priv->stream->next_out = (Bytef *) filter->outbuf + n;
 		} else {
 			priv->stream->avail_in += 8;
-			
+
 			if (priv->stream->avail_in > 0)
-				camel_mime_filter_backup (filter, priv->stream->next_in, priv->stream->avail_in);
-			
+				camel_mime_filter_backup (filter, (char *) priv->stream->next_in, priv->stream->avail_in);
+
 			break;
 		}
 	} while (1);
-	
+
 	/* FIXME: if we keep this, we could check that the gzip'd
 	 * stream is sane, but how would we tell our consumer if it
 	 * was/wasn't? */
 	/*priv->crc32 = crc32 (priv->crc32, in, len - priv->stream->avail_in - 8);
 	  priv->isize += len - priv->stream->avail_in - 8;*/
-	
+
 	*out = filter->outbuf;
 	*outlen = filter->outsize - priv->stream->avail_out;
 	*outprespace = filter->outpre;
