@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -103,6 +103,8 @@ int		camel_mime_part_construct_from_parser  (CamelMimePart *mime_part, CamelMime
 void      	camel_mime_part_set_content 	       (CamelMimePart *mime_part,
 							const char *content, int length, const char *type);
 
+size_t          camel_mime_part_get_content_size       (CamelMimePart *mime_part);
+
 G_END_DECLS
 
 #endif /* CAMEL_MIME_PART_H */
