@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -77,6 +77,8 @@ static void unsubscribe_folder (CamelStore *store, const char *folder_name, Came
 
 static void noop (CamelStore *store, CamelException *ex);
 
+static gboolean can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex);
+
 static void construct (CamelService *service, CamelSession *session,
 		       CamelProvider *provider, CamelURL *url,
 		       CamelException *ex);
@@ -109,13 +111,14 @@ camel_store_class_init (CamelStoreClass *camel_store_class)
 	camel_store_class->subscribe_folder = subscribe_folder;
 	camel_store_class->unsubscribe_folder = unsubscribe_folder;
 	camel_store_class->noop = noop;
-	
+	camel_store_class->can_refresh_folder = can_refresh_folder;
+
 	/* virtual method overload */
 	camel_service_class->construct = construct;
-	
+
 	camel_object_class->setv = store_setv;
 	camel_object_class->getv = store_getv;
-	
+
 	camel_object_class_add_event(camel_object_class, "folder_opened", NULL);
 	camel_object_class_add_event(camel_object_class, "folder_created", NULL);
 	camel_object_class_add_event(camel_object_class, "folder_deleted", NULL);
@@ -209,7 +212,7 @@ construct (CamelService *service, CamelSession *session,
 static CamelFolder *
 get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
 {
-	w(g_warning ("CamelStore::get_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::get_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 	
 	camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_INVALID,
@@ -226,33 +229,34 @@ get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelExce
  * @ex: a #CamelException
  *
  * Get a specific folder object from the store by name.
- * 
+ *
  * Returns the folder corresponding to the path @folder_name.
  **/
 CamelFolder *
 camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flags, CamelException *ex)
 {
 	CamelFolder *folder = NULL;
-	
+
+	g_return_val_if_fail (CAMEL_IS_STORE (store), NULL);
 	g_return_val_if_fail (folder_name != NULL, NULL);
-	
+
 	/* O_EXCL doesn't make sense if we aren't requesting to also create the folder if it doesn't exist */
 	if (!(flags & CAMEL_STORE_FOLDER_CREATE))
 		flags &= ~CAMEL_STORE_FOLDER_EXCL;
-	
+
 	if (store->folders) {
 		/* Try cache first. */
 		folder = camel_object_bag_reserve(store->folders, folder_name);
 		if (folder && (flags & CAMEL_STORE_FOLDER_EXCL)) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-					      _("Cannot create folder `%s': folder exists"),
+					      _("Cannot create folder '%s': folder exists"),
 					      folder_name);
-			
+                        camel_object_bag_abort (store->folders, folder_name);
 			camel_object_unref (folder);
 			return NULL;
 		}
 	}
-	
+
 	if (!folder) {
 		if ((store->flags & CAMEL_STORE_VTRASH) && strcmp(folder_name, CAMEL_VTRASH_NAME) == 0) {
 			folder = CS_CLASS(store)->get_trash(store, ex);
@@ -291,7 +295,7 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 	if (camel_debug_start(":store")) {
 		char *u = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_PASSWORD);
 
-		printf("CamelStore('%s'):get_folder('%s', %u) = %p\n", u, folder_name, flags, folder);
+		printf("CamelStore('%s'):get_folder('%s', %u) = %p\n", u, folder_name, flags, (void *) folder);
 		if (ex && ex->id)
 			printf("  failed: '%s'\n", ex->desc);
 		g_free(u);
@@ -305,7 +309,7 @@ static CamelFolderInfo *
 create_folder (CamelStore *store, const char *parent_name,
 	       const char *folder_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::create_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::create_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 	
 	camel_exception_setv (ex, CAMEL_EXCEPTION_STORE_INVALID,
@@ -380,7 +384,7 @@ cs_delete_cached_folder(CamelStore *store, const char *folder_name)
 static void
 delete_folder (CamelStore *store, const char *folder_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::delete_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::delete_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -422,7 +426,7 @@ camel_store_delete_folder (CamelStore *store, const char *folder_name, CamelExce
 static void
 rename_folder (CamelStore *store, const char *old_name, const char *new_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::rename_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::rename_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -670,7 +674,7 @@ camel_store_sync(CamelStore *store, int expunge, CamelException *ex)
 static CamelFolderInfo *
 get_folder_info (CamelStore *store, const char *top, guint32 flags, CamelException *ex)
 {
-	w(g_warning ("CamelStore::get_folder_info not implemented for `%s'",
+	w(g_warning ("CamelStore::get_folder_info not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 	
 	return NULL;
@@ -713,17 +717,17 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 		g_free (vinfo->uri);
 	} else {
 		/* There wasn't a Trash/Junk folder so create a new folder entry */
-		vinfo = g_new0 (CamelFolderInfo, 1);
-		
+		vinfo = camel_folder_info_new ();
+
 		g_assert(parent != NULL);
-		
+
 		vinfo->flags |= CAMEL_FOLDER_NOINFERIORS | CAMEL_FOLDER_SUBSCRIBED;
-		
+
 		/* link it into the right spot */
 		vinfo->next = parent->next;
 		parent->next = vinfo;
 	}
-	
+
 	/* Fill in the new fields */
 	vinfo->flags |= flags;
 	vinfo->full_name = g_strdup (name);
@@ -800,7 +804,7 @@ camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, C
 
 	if (camel_debug_start("store:folder_info")) {
 		char *url = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_ALL);
-		printf("Get folder info(%p:%s, '%s') =\n", store, url, top?top:"<null>");
+		printf("Get folder info(%p:%s, '%s') =\n", (void *) store, url, top?top:"<null>");
 		g_free(url);
 		dump_fi(info, 2);
 		camel_debug_end();
@@ -812,7 +816,7 @@ camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, C
 static void
 free_folder_info (CamelStore *store, CamelFolderInfo *fi)
 {
-	w(g_warning ("CamelStore::free_folder_info not implemented for `%s'",
+	w(g_warning ("CamelStore::free_folder_info not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -873,10 +877,21 @@ camel_folder_info_free (CamelFolderInfo *fi)
 		g_free (fi->name);
 		g_free (fi->full_name);
 		g_free (fi->uri);
-		g_free (fi);
+		g_slice_free (CamelFolderInfo, fi);
 	}
 }
 
+/**
+ * camel_folder_info_new:
+ *
+ * Return value: a new empty CamelFolderInfo instance
+ **/
+CamelFolderInfo *
+camel_folder_info_new (void)
+{
+	return g_slice_new0 (CamelFolderInfo);
+}
+
 static int
 folder_info_cmp (const void *ap, const void *bp)
 {
@@ -945,7 +960,7 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 				CamelURL *url;
 				char *sep;
 
-				pfi = g_new0 (CamelFolderInfo, 1);
+				pfi = camel_folder_info_new ();
 				if (short_names) {
 					pfi->name = strrchr (pname, separator);
 					if (pfi->name)
@@ -1014,7 +1029,7 @@ folder_info_clone_rec(CamelFolderInfo *fi, CamelFolderInfo *parent)
 {
 	CamelFolderInfo *info;
 
-	info = g_malloc(sizeof(*info));
+	info = camel_folder_info_new ();
 	info->parent = parent;
 	info->uri = g_strdup(fi->uri);
 	info->name = g_strdup(fi->name);
@@ -1071,7 +1086,7 @@ camel_store_supports_subscriptions (CamelStore *store)
 static gboolean
 folder_subscribed(CamelStore *store, const char *folder_name)
 {
-	w(g_warning ("CamelStore::folder_subscribed not implemented for `%s'",
+	w(g_warning ("CamelStore::folder_subscribed not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 	
 	return FALSE;
@@ -1106,7 +1121,7 @@ camel_store_folder_subscribed(CamelStore *store, const char *folder_name)
 static void
 subscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::subscribe_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::subscribe_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -1134,7 +1149,7 @@ camel_store_subscribe_folder(CamelStore *store, const char *folder_name, CamelEx
 static void
 unsubscribe_folder(CamelStore *store, const char *folder_name, CamelException *ex)
 {
-	w(g_warning ("CamelStore::unsubscribe_folder not implemented for `%s'",
+	w(g_warning ("CamelStore::unsubscribe_folder not implemented for '%s'",
 		     camel_type_to_name (CAMEL_OBJECT_GET_TYPE (store))));
 }
 
@@ -1246,6 +1261,33 @@ camel_store_folder_uri_equal (CamelStore *store, const char *uri0, const char *u
 	return equal;
 }
 
+static gboolean
+can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex)
+{
+	return ((info->flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_INBOX);
+}
+
+/**
+ * camel_store_can_refresh_folder
+ * Returns if this folder (param info) should be checked for new mail or not.
+ * It should not look into sub infos (info->child) or next infos, it should
+ * return value only for the actual folder info.
+ * Default behavior is that all Inbox folders are intended to be refreshed.
+ *
+ * @param store Store, to which belong folder.
+ * @param info Info of folder of our interest.
+ * @param ex [out] Will set this exception in case of any error.
+ * @return Whether folder should be checked for new mails or not.
+ **/
+gboolean
+camel_store_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex)
+{
+	g_return_val_if_fail (store != NULL, FALSE);
+	g_return_val_if_fail (info != NULL, FALSE);
+
+	return CS_CLASS (store)->can_refresh_folder (store, info, ex);	
+}
+
 /* subscriptions interface */
 
 static void
