@@ -29,14 +29,13 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <libedataserver/e-trie.h>
-
+#include "camel-trie.h"
 #include "camel-url-scanner.h"
 #include "camel-utf8.h"
 
 struct _CamelUrlScanner {
 	GPtrArray *patterns;
-	ETrie *trie;
+	CamelTrie *trie;
 };
 
 
@@ -44,11 +43,11 @@ CamelUrlScanner *
 camel_url_scanner_new (void)
 {
 	CamelUrlScanner *scanner;
-
+	
 	scanner = g_new (CamelUrlScanner, 1);
 	scanner->patterns = g_ptr_array_new ();
-	scanner->trie = e_trie_new (TRUE);
-
+	scanner->trie = camel_trie_new (TRUE);
+	
 	return scanner;
 }
 
@@ -57,9 +56,9 @@ void
 camel_url_scanner_free (CamelUrlScanner *scanner)
 {
 	g_return_if_fail (scanner != NULL);
-
+	
 	g_ptr_array_free (scanner->patterns, TRUE);
-	e_trie_free (scanner->trie);
+	camel_trie_free (scanner->trie);
 	g_free (scanner);
 }
 
@@ -68,8 +67,8 @@ void
 camel_url_scanner_add (CamelUrlScanner *scanner, urlpattern_t *pattern)
 {
 	g_return_if_fail (scanner != NULL);
-
-	e_trie_add (scanner->trie, pattern->pattern, scanner->patterns->len);
+	
+	camel_trie_add (scanner->trie, pattern->pattern, scanner->patterns->len);
 	g_ptr_array_add (scanner->patterns, pattern);
 }
 
@@ -81,32 +80,32 @@ camel_url_scanner_scan (CamelUrlScanner *scanner, const char *in, size_t inlen,
 	const unsigned char *inptr, *inend;
 	urlpattern_t *pat;
 	int pattern;
-
+	
 	g_return_val_if_fail (scanner != NULL, FALSE);
 	g_return_val_if_fail (in != NULL, FALSE);
-
+	
 	inptr = (const unsigned char *) in;
 	inend = inptr + inlen;
-
+	
 	do {
-		if (!(pos = e_trie_search (scanner->trie, (const char *)inptr, inlen, &pattern)))
+		if (!(pos = camel_trie_search (scanner->trie, (const char *)inptr, inlen, &pattern)))
 			return FALSE;
-
+		
 		pat = g_ptr_array_index (scanner->patterns, pattern);
-
+		
 		match->pattern = pat->pattern;
 		match->prefix = pat->prefix;
-
+		
 		if (pat->start (in, pos, (const char *)inend, match) && pat->end (in, pos, (const char *)inend, match))
 			return TRUE;
-
+		
 		inptr = (const unsigned char *) pos;
 		if (camel_utf8_getc_limit (&inptr, inend) == 0xffff)
 			break;
-
+		
 		inlen = inend - inptr;
 	} while (inptr < inend);
-
+	
 	return FALSE;
 }
 
@@ -166,12 +165,12 @@ static gboolean
 is_open_brace (char c)
 {
 	int i;
-
+	
 	for (i = 0; i < G_N_ELEMENTS (url_braces); i++) {
 		if (c == url_braces[i].open)
 			return TRUE;
 	}
-
+	
 	return FALSE;
 }
 
@@ -186,13 +185,13 @@ url_stop_at_brace (const char *in, size_t so, char *open_brace)
 	if (so > 0) {
 		for (i = 0; i < G_N_ELEMENTS (url_braces); i++) {
 			if (in[so - 1] == url_braces[i].open) {
-				if (open_brace != NULL)
+				if (open_brace != NULL) 
 					*open_brace = url_braces[i].open;
 				return url_braces[i].close;
 			}
 		}
 	}
-
+	
 	return '\0';
 }
 
@@ -201,33 +200,33 @@ gboolean
 camel_url_addrspec_start (const char *in, const char *pos, const char *inend, urlmatch_t *match)
 {
 	register const char *inptr = pos;
-
+	
 	g_assert (*inptr == '@');
-
+	
 	if (inptr > in)
 		inptr--;
-
+	
 	while (inptr > in) {
 		if (is_atom (*inptr))
 			inptr--;
 		else
 			break;
-
+		
 		while (inptr > in && is_atom (*inptr))
 			inptr--;
-
+		
 		if (inptr > in && *inptr == '.')
 			inptr--;
 	}
-
+	
 	while (!is_atom (*inptr) || is_open_brace (*inptr))
 		inptr++;
-
+	
 	if (inptr >= pos)
 		return FALSE;
-
+	
 	match->um_so = (inptr - in);
-
+	
 	return TRUE;
 }
 
@@ -237,33 +236,33 @@ camel_url_addrspec_end (const char *in, const char *pos, const char *inend, urlm
 	const char *inptr = pos;
 	int parts = 0, digits;
 	gboolean got_dot = FALSE;
-
+	
 	g_assert (*inptr == '@');
-
+	
 	inptr++;
-
+	
 	if (*inptr == '[') {
 		/* domain literal */
 		do {
 			inptr++;
-
+			
 			digits = 0;
 			while (inptr < inend && is_digit (*inptr) && digits < 3) {
 				inptr++;
 				digits++;
 			}
-
+			
 			parts++;
-
+			
 			if (*inptr != '.' && parts != 4)
 				return FALSE;
 		} while (parts < 4);
-
+		
 		if (*inptr == ']')
 			inptr++;
 		else
 			return FALSE;
-
+		
 		got_dot = TRUE;
 	} else {
 		while (inptr < inend) {
@@ -271,10 +270,10 @@ camel_url_addrspec_end (const char *in, const char *pos, const char *inend, urlm
 				inptr++;
 			else
 				break;
-
+			
 			while (inptr < inend && is_domain (*inptr))
 				inptr++;
-
+			
 			if (inptr < inend && *inptr == '.' && is_domain (inptr[1])) {
 				if (*inptr == '.')
 					got_dot = TRUE;
@@ -282,13 +281,13 @@ camel_url_addrspec_end (const char *in, const char *pos, const char *inend, urlm
 			}
 		}
 	}
-
+	
 	/* don't allow toplevel domains */
 	if (inptr == pos + 1 || !got_dot)
 		return FALSE;
-
+	
 	match->um_eo = (inptr - in);
-
+	
 	return TRUE;
 }
 
@@ -296,7 +295,7 @@ gboolean
 camel_url_file_start (const char *in, const char *pos, const char *inend, urlmatch_t *match)
 {
 	match->um_so = (pos - in);
-
+	
 	return TRUE;
 }
 
@@ -305,22 +304,22 @@ camel_url_file_end (const char *in, const char *pos, const char *inend, urlmatch
 {
 	register const char *inptr = pos;
 	char close_brace;
-
+	
 	inptr += strlen (match->pattern);
-
+	
 	if (*inptr == '/')
 		inptr++;
-
+	
 	close_brace = url_stop_at_brace (in, match->um_so, NULL);
-
+	
 	while (inptr < inend && is_urlsafe (*inptr) && *inptr != close_brace)
 		inptr++;
-
+	
 	if (inptr == pos)
 		return FALSE;
-
+	
 	match->um_eo = (inptr - in);
-
+	
 	return TRUE;
 }
 
@@ -332,9 +331,9 @@ camel_url_web_start (const char *in, const char *pos, const char *inend, urlmatc
 		if (!is_open_brace (pos[-1]) && !isspace (pos[-1]))
 			return FALSE;
 	}
-
+	
 	match->um_so = (pos - in);
-
+	
 	return TRUE;
 }
 
@@ -349,7 +348,7 @@ camel_url_web_end (const char *in, const char *pos, const char *inend, urlmatch_
 	int port;
 
 	inptr += strlen (match->pattern);
-
+	
 	close_brace = url_stop_at_brace (in, match->um_so, &open_brace);
 
 	/* find the end of the domain */
@@ -359,81 +358,81 @@ camel_url_web_end (const char *in, const char *pos, const char *inend, urlmatch_
 		while (inptr < inend) {
 			if (!is_atom (*inptr))
 				break;
-
+			
 			inptr++;
-
+			
 			while (inptr < inend && is_atom (*inptr))
 				inptr++;
-
-			if ((inptr + 1) < inend && *inptr == '.' && (is_atom (inptr[1]) || inptr[1] == '/'))
+			
+			if ((inptr + 1) < inend && *inptr == '.' && (is_atom (inptr[1]) || inptr[1] == '/')) 
 					inptr++;
 		}
-
+		
 		if (*inptr != '@')
 			inptr = save;
 		else
 			inptr++;
-
+		
 		goto domain;
 	} else if (is_domain (*inptr)) {
 	domain:
 		while (inptr < inend) {
 			if (!is_domain (*inptr))
 				break;
-
+			
 			inptr++;
-
+			
 			while (inptr < inend && is_domain (*inptr))
 				inptr++;
-
-			if ((inptr + 1) < inend && *inptr == '.' && (is_domain (inptr[1]) || inptr[1] == '/'))
+			
+			if ((inptr + 1) < inend && *inptr == '.' && (is_domain (inptr[1]) || inptr[1] == '/')) 
 					inptr++;
 		}
 	} else {
 		return FALSE;
 	}
-
+	
 	if (inptr < inend) {
 		switch (*inptr) {
 		case ':': /* we either have a port or a password */
 			inptr++;
-
+			
 			if (is_digit (*inptr) || passwd) {
 				port = (*inptr++ - '0');
-
+				
 				while (inptr < inend && is_digit (*inptr) && port < 65536)
 					port = (port * 10) + (*inptr++ - '0');
-
+				
 				if (!passwd && (port >= 65536 || *inptr == '@')) {
 					if (inptr < inend) {
 						/* this must be a password? */
 						goto passwd;
 					}
-
+					
 					inptr--;
 				}
 			} else {
 			passwd:
 				passwd = TRUE;
 				save = inptr;
-
+				
 				while (inptr < inend && is_atom (*inptr))
 					inptr++;
-
+				
 				if ((inptr + 2) < inend) {
 					if (*inptr == '@') {
 						inptr++;
 						if (is_domain (*inptr))
 							goto domain;
 					}
-
+					
 					return FALSE;
 				}
 			}
-
+			
 			if (inptr >= inend || *inptr != '/')
 				break;
-
+			
 			/* we have a '/' so there could be a path - fall through */
 		case '/': /* we've detected a path component to our url */
 			inptr++;
@@ -466,7 +465,7 @@ camel_url_web_end (const char *in, const char *pos, const char *inend, urlmatch_
 
 
 	match->um_eo = (inptr - in);
-
+	
 	return TRUE;
 }
 
@@ -488,7 +487,7 @@ static void
 table_init_bits (unsigned int mask, const unsigned char *vals)
 {
 	int i;
-
+	
 	for (i = 0; vals[i] != '\0'; i++)
 		url_scanner_table[vals[i]] |= mask;
 }
@@ -497,7 +496,7 @@ static void
 url_scanner_table_init (void)
 {
 	int i;
-
+	
 	for (i = 0; i < 256; i++) {
 		url_scanner_table[i] = 0;
 		if (i < 32)
@@ -509,16 +508,16 @@ url_scanner_table_init (void)
 		if (i >= 127)
 			url_scanner_table[i] |= IS_CTRL;
 	}
-
+	
 	url_scanner_table[' '] |= IS_SPACE;
 	url_scanner_table['-'] |= IS_DOMAIN;
-
+	
 	/* not defined to be special in rfc0822, but when scanning
            backwards to find the beginning of the email address we do
            not want to include this char if we come accross it - so
            this is kind of a hack */
 	url_scanner_table['/'] |= IS_SPECIAL;
-
+	
 	table_init_bits (IS_LWSP, CHARS_LWSP);
 	table_init_bits (IS_SPECIAL, CHARS_SPECIAL);
 	table_init_bits (IS_URLSAFE, CHARS_URLSAFE);
@@ -527,16 +526,16 @@ url_scanner_table_init (void)
 int main (int argc, char **argv)
 {
 	int i;
-
+	
 	url_scanner_table_init ();
-
+	
 	printf ("static unsigned char url_scanner_table[256] = {");
 	for (i = 0; i < 256; i++) {
 		printf ("%s%3d%s", (i % 16) ? "" : "\n\t",
 			url_scanner_table[i], i != 255 ? "," : "\n");
 	}
 	printf ("};\n\n");
-
+	
 	return 0;
 }
 
