@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -25,25 +25,26 @@
 #include <config.h>
 #endif
 
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <fcntl.h>
 #include <ctype.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
-#include <camel/camel-i18n.h>
-#include <camel/camel-folder.h>
-#include <camel/camel-file-utils.h>
-#include <camel/camel-folder-summary.h>
-#include <camel/camel-data-cache.h>
+#include <glib.h>
+#include <glib/gi18n-lib.h>
+
+#include "camel-data-cache.h"
+#include "camel-file-utils.h"
+#include "camel-folder-summary.h"
+#include "camel-folder.h"
 
 #include "camel-groupwise-folder.h"
-#include "camel-groupwise-store.h"
 #include "camel-groupwise-journal.h"
-
+#include "camel-groupwise-store.h"
 
 #define d(x) x
 
@@ -64,7 +65,7 @@ static CamelOfflineJournalClass *parent_class = NULL;
 CamelType
 camel_groupwise_journal_get_type (void)
 {
-	static CamelType type = 0;
+	static CamelType type = NULL;
 	
 	if (!type) {
 		type = camel_type_register (camel_offline_journal_get_type (),
