@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef _CAMEL_SPOOL_SUMMARY_H
@@ -31,6 +31,8 @@
 #define CAMEL_SPOOL_SUMMARY_CLASS(klass) CAMEL_CHECK_CLASS_CAST (klass, camel_spool_summary_get_type (), CamelSpoolSummaryClass)
 #define CAMEL_IS_SPOOL_SUMMARY(obj)      CAMEL_CHECK_TYPE (obj, camel_spool_summary_get_type ())
 
+G_BEGIN_DECLS
+
 typedef struct _CamelSpoolSummary      CamelSpoolSummary;
 typedef struct _CamelSpoolSummaryClass CamelSpoolSummaryClass;
 
@@ -65,5 +67,6 @@ int camel_spool_summary_decode_x_evolution(CamelSpoolSummary *cls, const char *x
 /* utility functions - write headers to a file with optional X-Evolution header */
 int camel_spool_summary_write_headers(int fd, struct _camel_header_raw *header, char *xevline);
 
-#endif /* ! _CAMEL_SPOOL_SUMMARY_H */
+G_END_DECLS
 
+#endif /* ! _CAMEL_SPOOL_SUMMARY_H */
