@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Rodrigo Moya <rodrigo@ximian.com>
  */
@@ -24,15 +24,16 @@
 
 #include <pthread.h>
 #include <sys/types.h>
-#include <glib/gmacros.h>
-#include <glib/gtypes.h>
-#include <glib/gunicode.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
 struct tm;
 
+#ifndef EDS_DISABLE_DEPRECATED
+G_GNUC_DEPRECATED
 int          e_util_mkdir_hier (const char *path, mode_t mode);
+#endif
 
 gchar       *e_util_strstrcase (const gchar *haystack, const gchar *needle);
 gchar       *e_util_unicode_get_utf8 (const gchar *text, gunichar *out);
