@@ -26,10 +26,16 @@
 #include <config.h>
 #endif
 
-#include <netinet/in.h>
-#include <sys/socket.h>
 #include <string.h>
 #include <stdlib.h>
+
+#ifdef _WIN32
+#include <winsock2.h>
+#else
+#include <netinet/in.h>
+#include <sys/socket.h>
+#endif
+
 #include <glib.h>
 #include <glib-object.h>
 
@@ -162,11 +168,12 @@ static void
 e_proxy_dispose (GObject *object)
 {
 	EProxy *proxy = (EProxy *)object;
+	EProxyPrivate *priv;
 	
 	if (!E_IS_PROXY (proxy))
 		return;
 
-	EProxyPrivate *priv = proxy->priv;
+	priv = proxy->priv;
 
 	if (priv) {
 		GConfClient* client = NULL;
